Welcome to trumpet's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   modules
   contributing
   authors
   history
   former-env-setup
   TrumpetStaticResources
   WebViews
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
